#!/usr/bin/webif-page
<?
. /usr/lib/webif/webif.sh

validate <<EOF
string|FORM_submit|@TR<<Submit>>|max=10|$FORM_submit
EOF

if [ "$?" != "0" ]
then
	FORM_submit=""
fi

load_settings fon
if empty "$FORM_submit"; then
	get_default ssid private essid
	get_default enc private encryption
	get_default crypto private wpa_crypto
	case "${FORM_enc##/*}" in
		wep|WEP) FORM_auth=wep;;
		WPA|WPA1|wpa|wpa1) FORM_auth=wpa;;
		WPA2|wpa2) FORM_auth=wpa2;;
		mixed|Mixed) FORM_auth=mixed;;
		*) FORM_auth=open;;
	esac
	case "${FORM_crypto}" in
		aes|AES|ccmp|CCMP) FORM_crypto="aes";;
		tkip|TKIP) FORM_crypto="tkip";;
		tkip+aes|TKIP+AES|aes+tkip|AES+TKIP) FORM_crypto="tkip+aes";;
		*) FORM_crypto=tkip+aes;;
	esac
	get_default psk private password
	get_default wepkey private wepkey
	get_default key1 private key1
	get_default key2 private key2
	get_default key3 private key3
	get_default key4 private key4
else
	validate <<EOF
string|FORM_ssid|@TR<<ESSID>>|required max=28|$FORM_ssid
chk_auth|FORM_auth|@TR<<Authentication>>||$FORM_auth
int|FORM_wepkey|@TR<<Selected WEP Key>>|min=1 max=4|$FORM_wepkey
chk_crypto|FORM_crypto|@TR<<Cipher>>||$FORM_crypto
EOF

equal "$?" 0 && {
	case "$FORM_auth" in
		wpa|wpa2|mixed) V_PSK="required";;
		wep)
			eval "V_K$FORM_wepkey=required"
		;;
	esac

	validate <<EOF
string|FORM_psk|@TR<<WPA Passphrase>>|min=8 max=63 $V_PSK|$FORM_psk
wep|FORM_key1|@TR<<WEP Key>> 1|$V_K1|$FORM_key1
wep|FORM_key2|@TR<<WEP Key>> 2|$V_K2|$FORM_key2
wep|FORM_key3|@TR<<WEP Key>> 3|$V_K3|$FORM_key3
wep|FORM_key4|@TR<<WEP Key>> 4|$V_K4|$FORM_key4
EOF
	equal "$?" 0 && {
		save_setting fon private essid "$FORM_ssid"
		case "$FORM_auth" in
			wpa|wpa2|mixed)
				save_setting fon private encryption "$FORM_auth"
				save_setting fon private wpa_crypto "$FORM_crypto"
				save_setting fon private password "$FORM_psk"
			;;
			wep)
				save_setting fon private encryption wep
				save_setting fon private wepkey "$FORM_wepkey"
				save_setting fon private key1 "$FORM_key1"
				save_setting fon private key2 "$FORM_key2"
				save_setting fon private key3 "$FORM_key3"
				save_setting fon private key4 "$FORM_key4"
			;;
			*)
				save_setting fon private encryption open
			;;
		esac
		commit_settings
		ifup lan >/dev/null 2>/dev/null </dev/null &
		SAVED=1
	}
}
fi

header "Priv_Title#Private Wireless Settings"

cat <<EOF
<script type="text/javascript">
<!--
function modechange() {
	var v = isset('auth', 'wpa') || isset('auth', 'wpa2') || isset('auth', 'mixed');
	set_visible('wpa_stuff', v);
	set_visible('wep_stuff', isset('auth', 'wep'));
}
-->
</script>
EOF

display_form <<EOF
	infotable|PRE_PRIV_SSID#This is the name of the signal for your personal use.

	start_table|0|10|5
		onchange|modechange
		add_row
			add_label_cell|@TR<<SSID#Name (SSID)>>
			add_input_cell|ssid|$FORM_ssid|tableTextButton
		end_row
		add_row
			add_label_cell|@TR<<Authentication>>
			start_select_cell|auth|$FORM_auth|tableTextSelect
				option|open|@TR<<Open>>
				option|wep|WEP
				option|wpa|WPA
				option|wpa2|WPA2
				option|mixed|@TR<<WPA/WPA2-Mixed>>
			end_select_cell
		end_row
	end_table

	start_div|wpa_stuff
		start_table|0|10|5
			add_row
				add_label_cell|@TR<<Cipher>>
				start_select_cell|crypto|$FORM_crypto|tableTextSelect
					option|tkip+aes|@TR<<Mixed>>
					option|tkip|TKIP
					option|aes|AES
				end_select_cell
			end_row
			add_row
				add_label_cell|@TR<<WPA Passphrase>>
				add_input_cell|psk|$FORM_psk|tableTextButton
			end_row
		end_table
	end_div

	start_div|wep_stuff
		start_table|0|10|5
			add_row
				add_label_cell|@TR<<Use key>>
				start_select_cell|wepkey|$FORM_wepkey|tableTextSelect
					option|1|1
					option|2|2
					option|3|3
					option|4|4
				end_select_cell
			end_row
			add_row
				add_label_cell|@TR<<Key 1>>
				add_input_cell|key1|$FORM_key1|tableTextButton
			end_row
			add_row
				add_label_cell|@TR<<Key 2>>
				add_input_cell|key2|$FORM_key2|tableTextButton
			end_row
			add_row
				add_label_cell|@TR<<Key 3>>
				add_input_cell|key3|$FORM_key3|tableTextButton
			end_row
			add_row
				add_label_cell|@TR<<Key 4>>
				add_input_cell|key4|$FORM_key4|tableTextButton
			end_row
		end_table
	end_div
	start_table|0|10|5
		add_row
			add_button_cell|submit|@TR<<Submit>>
		end_row
	end_table
EOF

cat <<EOF
<script type="text/javascript">
<!--
modechange();
-->
</script>
EOF

footer ?>